==> estateplat-common-1.2.3-20180710.111402-148-sources.jar: cn/gtmap/estateplat/model/server/core/BdcCf.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Table;
import java.util.Date;

/**
 * 查封登记信息
 * Created by lst on 2015/3/18
 */
@Table(name = "bdc_cf")
public class BdcCf extends QllxParent implements QllxVo{
    //     private String qlid;//权利Id
    //    private String bdcdyid;//不动产单元Id
    private String cfjg;//查封机关
    private String cflx;//查封类型
    private String cfwh;//查封文号
    private String cffw;//查封范围
    private String jfywh;//解封业务号
    private String jfjg;//解封机关
    private String jfwj;//解封文件
    private String jfwh;//解封文号
    private Date jfsj;//解封时间
    private Date jfdjsj;//解封登记时间
    private String jfdbr;//解封登簿人
    private Date cfksqx;//查封开始期限
    private Date cfjsqx;//查封结束期限
    private String zxsqr;//执行申请人
    private String bzxr;//被执行人
    private String cfyy;//查封原因
    private Integer lhsx;//轮候顺序
    private String ywh;//业务号
    private String qllx;//权利类型
    //    private String proid;//项目ID
    private String gyqk;//共有情况
    private Date djsj;//登记时间
    private String dbr;//登簿人
    private String fj;//附记
    private Integer qszt;//权属状态
    private Date cfsj;//查封送达时间
    private String cfwj;//zdd 查封文件
    private String cfsqr;//查封申请人

    private String lhcfqx;//轮候查封期限
    private String fysdr;//法院送达人
    private String fysdrlxfs;//法院送达人联系方式
    private String fysdrzjhm;//法院送达人证件号码
    private String ysxkzmh;//预售许可证明号
    private String jflx;//解封类型
    private String issx;//是否失效
    private String iscd;//是否裁定
    private String bz;//备注
    private Integer cfsx;//查封顺序
    private Date xfjssj;//续封结束时间

    /**
     * @author <a href="mailto:liujie@gtmap.cn">liujie</a>
     * @description bdc_cf表增加冗余字段qlrzjzl、qlrzjh、ywrzjzl、ywrzjh、bdcdyh、bdcqzh、bdcdybh、zl
     */
    private String qlrzjzl; //权利人证件种类

    private String qlrzjh; //权利人证件号

    private String ywrzjzl; //义务人证件种类

    private String ywrzjh; //义务人证件号

    private String bdcdyh; //不动产单元号

    private String bdcqzh; //不动产权证号

    private String bdcdybh; //不动产单元编号

    private String zl; //坐落

    public String getQlrzjzl() {
        return qlrzjzl;
    }

    public void setQlrzjzl(String qlrzjzl) {
        this.qlrzjzl = qlrzjzl;
    }

    public String getQlrzjh() {
        return qlrzjh;
    }

    public void setQlrzjh(String qlrzjh) {
        this.qlrzjh = qlrzjh;
    }

    public String getYwrzjzl() {
        return ywrzjzl;
    }

    public void setYwrzjzl(String ywrzjzl) {
        this.ywrzjzl = ywrzjzl;
    }

    public String getYwrzjh() {
        return ywrzjh;
    }

    public void setYwrzjh(String ywrzjh) {
        this.ywrzjh = ywrzjh;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getBdcqzh() {
        return bdcqzh;
    }

    public void setBdcqzh(String bdcqzh) {
        this.bdcqzh = bdcqzh;
    }

    public String getBdcdybh() {
        return bdcdybh;
    }

    public void setBdcdybh(String bdcdybh) {
        this.bdcdybh = bdcdybh;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getFysdrzjhm() {
        return fysdrzjhm;
    }

    public void setFysdrzjhm(String fysdrzjhm) {
        this.fysdrzjhm = fysdrzjhm;
    }

    public String getYsxkzmh() {
        return ysxkzmh;
    }

    public void setYsxkzmh(String ysxkzmh) {
        this.ysxkzmh = ysxkzmh;
    }

    public Date getCfsj() {
        return cfsj;
    }

    public void setCfsj(Date cfsj) {
        this.cfsj = cfsj;
    }

    public String getFysdr() {
        return fysdr;
    }

    public void setFysdr(String fysdr) {
        this.fysdr = fysdr;
    }

    public String getFysdrlxfs() {
        return fysdrlxfs;
    }

    public void setFysdrlxfs(String fysdrlxfs) {
        this.fysdrlxfs = fysdrlxfs;
    }

    public BdcCf() {
    }

    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }


    public Integer getQszt() {
        return qszt;
    }

    public void setQszt(Integer qszt) {
        this.qszt = qszt;
    }


    public String getQlid() {
        return qlid;
    }

    public void setQlid(String qlid) {
        this.qlid = qlid;
    }

    public String getBdcdyid() {
        return bdcdyid;
    }

    public void setBdcdyid(String bdcdyid) {
        this.bdcdyid = bdcdyid;
    }

    public String getCfwj() {
        return cfwj;
    }

    public void setCfwj(String cfwj) {
        this.cfwj = cfwj;
    }

    public String getCfjg() {
        return cfjg;
    }

    public void setCfjg(String cfjg) {
        this.cfjg = cfjg;
    }

    public String getCflx() {
        return cflx;
    }

    public void setCflx(String cflx) {
        this.cflx = cflx;
    }

    public String getCfwh() {
        return cfwh;
    }

    public void setCfwh(String cfwh) {
        this.cfwh = cfwh;
    }

    public String getCffw() {
        return cffw;
    }

    public void setCffw(String cffw) {
        this.cffw = cffw;
    }

    public String getJfywh() {
        return jfywh;
    }

    public void setJfywh(String jfywh) {
        this.jfywh = jfywh;
    }

    public String getJfjg() {
        return jfjg;
    }

    public void setJfjg(String jfjg) {
        this.jfjg = jfjg;
    }

    public String getJfwj() {
        return jfwj;
    }

    public void setJfwj(String jfwj) {
        this.jfwj = jfwj;
    }

    public String getJfwh() {
        return jfwh;
    }

    public void setJfwh(String jfwh) {
        this.jfwh = jfwh;
    }

    public Date getJfsj() {
        return jfsj;
    }

    public void setJfsj(Date jfsj) {
        this.jfsj = jfsj;
    }

    public Date getJfdjsj() {
        return jfdjsj;
    }

    public void setJfdjsj(Date jfdjsj) {
        this.jfdjsj = jfdjsj;
    }

    public String getJfdbr() {
        return jfdbr;
    }

    public void setJfdbr(String jfdbr) {
        this.jfdbr = jfdbr;
    }

    public Date getCfksqx() {
        return cfksqx;
    }

    public void setCfksqx(Date cfksqx) {
        this.cfksqx = cfksqx;
    }

    public Date getCfjsqx() {
        return cfjsqx;
    }

    public void setCfjsqx(Date cfjsqx) {
        this.cfjsqx = cfjsqx;
    }

    public String getZxsqr() {
        return zxsqr;
    }

    public void setZxsqr(String zxsqr) {
        this.zxsqr = zxsqr;
    }

    public String getBzxr() {
        return bzxr;
    }

    public void setBzxr(String bzxr) {
        this.bzxr = bzxr;
    }

    public String getCfyy() {
        return cfyy;
    }

    public void setCfyy(String cfyy) {
        this.cfyy = cfyy;
    }


    public Integer getLhsx() {
        return lhsx;
    }

    public void setLhsx(Integer lhsx) {
        this.lhsx = lhsx;
    }


    public String getQllx() {
        return qllx;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public String getGyqk() {
        return gyqk;
    }

    public void setGyqk(String gyqk) {
        this.gyqk = gyqk;
    }

    public Date getDjsj() {
        return djsj;
    }

    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }

    public String getDbr() {
        return dbr;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    public String getFj() {
        return fj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }

    public String getCfsqr() {
        return cfsqr;
    }

    public void setCfsqr(String cfsqr) {
        this.cfsqr = cfsqr;
    }


    public String getLhcfqx() {
        return lhcfqx;
    }

    public void setLhcfqx(String lhcfqx) {
        this.lhcfqx = lhcfqx;
    }

    public String getJflx() {
        return jflx;
    }

    public void setJflx(String jflx) {
        this.jflx = jflx;
    }

    public String getIssx() {
        return issx;
    }

    public void setIssx(String issx) {
        this.issx = issx;
    }

    public String getIscd() {
        return iscd;
    }

    public void setIscd(String iscd) {
        this.iscd = iscd;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public Integer getCfsx() {
        return cfsx;
    }

    public void setCfsx(Integer cfsx) {
        this.cfsx = cfsx;
    }

    public Date getXfjssj() {
        return xfjssj;
    }

    public void setXfjssj(Date xfjssj) {
        this.xfjssj = xfjssj;
    }
}

==> estateplat-common-1.2.3-20180824.030911-169-sources.jar: cn/gtmap/estateplat/model/server/core/BdcCf.java <==
package cn.gtmap.estateplat.model.server.core;

import org.springframework.format.annotation.DateTimeFormat;

import javax.persistence.Table;
import java.util.Date;

/**
 * 查封登记信息
 * Created by lst on 2015/3/18
 */
@Table(name = "bdc_cf")
public class BdcCf extends QllxParent implements QllxVo{
    //     private String qlid;//权利Id
    //    private String bdcdyid;//不动产单元Id
    private String cfjg;//查封机关
    private String cflx;//查封类型
    private String cfwh;//查封文号
    private String cffw;//查封范围
    private String jfywh;//解封业务号
    private String jfjg;//解封机关
    private String jfwj;//解封文件
    private String jfwh;//解封文号
    private Date jfsj;//解封时间
    private Date jfdjsj;//解封登记时间
    private String jfdbr;//解封登簿人
    private Date cfksqx;//查封开始期限
    private Date cfjsqx;//查封结束期限
    private String zxsqr;//执行申请人
    private String bzxr;//被执行人
    private String cfyy;//查封原因
    private Integer lhsx;//轮候顺序
    private String ywh;//业务号
    private String qllx;//权利类型
    //    private String proid;//项目ID
    private String gyqk;//共有情况
    private Date djsj;//登记时间
    private String dbr;//登簿人
    private String fj;//附记
    private Integer qszt;//权属状态
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    private Date cfsj;//查封送达时间
    private String cfwj;//zdd 查封文件
    private String cfsqr;//查封申请人

    private String lhcfqx;//轮候查封期限
    private String fysdr;//法院送达人
    private String fysdrlxfs;//法院送达人联系方式
    private String fysdrzjhm;//法院送达人证件号码
    private String ysxkzmh;//预售许可证明号
    private String jflx;//解封类型
    private String issx;//是否失效
    private String iscd;//是否裁定
    private String bz;//备注
    private Integer cfsx;//查封顺序
    private Date xfjssj;//续封结束时间

    /**
     * @author <a href="mailto:liujie@gtmap.cn">liujie</a>
     * @description bdc_cf表增加冗余字段qlrzjzl、qlrzjh、ywrzjzl、ywrzjh、bdcdyh、bdcqzh、bdcdybh、zl
     */
    private String qlrzjzl; //权利人证件种类

    private String qlrzjh; //权利人证件号

    private String ywrzjzl; //义务人证件种类

    private String ywrzjh; //义务人证件号

    private String bdcdyh; //不动产单元号

    private String bdcqzh; //不动产权证号

    private String bdcdybh; //不动产单元编号

    private String zl; //坐落

    public String getQlrzjzl() {
        return qlrzjzl;
    }

    public void setQlrzjzl(String qlrzjzl) {
        this.qlrzjzl = qlrzjzl;
    }

    public String getQlrzjh() {
        return qlrzjh;
    }

    public void setQlrzjh(String qlrzjh) {
        this.qlrzjh = qlrzjh;
    }

    public String getYwrzjzl() {
        return ywrzjzl;
    }

    public void setYwrzjzl(String ywrzjzl) {
        this.ywrzjzl = ywrzjzl;
    }

    public String getYwrzjh() {
        return ywrzjh;
    }

    public void setYwrzjh(String ywrzjh) {
        this.ywrzjh = ywrzjh;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getBdcqzh() {
        return bdcqzh;
    }

    public void setBdcqzh(String bdcqzh) {
        this.bdcqzh = bdcqzh;
    }

    public String getBdcdybh() {
        return bdcdybh;
    }

    public void setBdcdybh(String bdcdybh) {
        this.bdcdybh = bdcdybh;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getFysdrzjhm() {
        return fysdrzjhm;
    }

    public void setFysdrzjhm(String fysdrzjhm) {
        this.fysdrzjhm = fysdrzjhm;
    }

    public String getYsxkzmh() {
        return ysxkzmh;
    }

    public void setYsxkzmh(String ysxkzmh) {
        this.ysxkzmh = ysxkzmh;
    }

    public Date getCfsj() {
        return cfsj;
    }

    public void setCfsj(Date cfsj) {
        this.cfsj = cfsj;
    }

    public String getFysdr() {
        return fysdr;
    }

    public void setFysdr(String fysdr) {
        this.fysdr = fysdr;
    }

    public String getFysdrlxfs() {
        return fysdrlxfs;
    }

    public void setFysdrlxfs(String fysdrlxfs) {
        this.fysdrlxfs = fysdrlxfs;
    }

    public BdcCf() {
    }

    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }


    public Integer getQszt() {
        return qszt;
    }

    public void setQszt(Integer qszt) {
        this.qszt = qszt;
    }


    public String getQlid() {
        return qlid;
    }

    public void setQlid(String qlid) {
        this.qlid = qlid;
    }

    public String getBdcdyid() {
        return bdcdyid;
    }

    public void setBdcdyid(String bdcdyid) {
        this.bdcdyid = bdcdyid;
    }

    public String getCfwj() {
        return cfwj;
    }

    public void setCfwj(String cfwj) {
        this.cfwj = cfwj;
    }

    public String getCfjg() {
        return cfjg;
    }

    public void setCfjg(String cfjg) {
        this.cfjg = cfjg;
    }

    public String getCflx() {
        return cflx;
    }

    public void setCflx(String cflx) {
        this.cflx = cflx;
    }

    public String getCfwh() {
        return cfwh;
    }

    public void setCfwh(String cfwh) {
        this.cfwh = cfwh;
    }

    public String getCffw() {
        return cffw;
    }

    public void setCffw(String cffw) {
        this.cffw = cffw;
    }

    public String getJfywh() {
        return jfywh;
    }

    public void setJfywh(String jfywh) {
        this.jfywh = jfywh;
    }

    public String getJfjg() {
        return jfjg;
    }

    public void setJfjg(String jfjg) {
        this.jfjg = jfjg;
    }

    public String getJfwj() {
        return jfwj;
    }

    public void setJfwj(String jfwj) {
        this.jfwj = jfwj;
    }

    public String getJfwh() {
        return jfwh;
    }

    public void setJfwh(String jfwh) {
        this.jfwh = jfwh;
    }

    public Date getJfsj() {
        return jfsj;
    }

    public void setJfsj(Date jfsj) {
        this.jfsj = jfsj;
    }

    public Date getJfdjsj() {
        return jfdjsj;
    }

    public void setJfdjsj(Date jfdjsj) {
        this.jfdjsj = jfdjsj;
    }

    public String getJfdbr() {
        return jfdbr;
    }

    public void setJfdbr(String jfdbr) {
        this.jfdbr = jfdbr;
    }

    public Date getCfksqx() {
        return cfksqx;
    }

    public void setCfksqx(Date cfksqx) {
        this.cfksqx = cfksqx;
    }

    public Date getCfjsqx() {
        return cfjsqx;
    }

    public void setCfjsqx(Date cfjsqx) {
        this.cfjsqx = cfjsqx;
    }

    public String getZxsqr() {
        return zxsqr;
    }

    public void setZxsqr(String zxsqr) {
        this.zxsqr = zxsqr;
    }

    public String getBzxr() {
        return bzxr;
    }

    public void setBzxr(String bzxr) {
        this.bzxr = bzxr;
    }

    public String getCfyy() {
        return cfyy;
    }

    public void setCfyy(String cfyy) {
        this.cfyy = cfyy;
    }


    public Integer getLhsx() {
        return lhsx;
    }

    public void setLhsx(Integer lhsx) {
        this.lhsx = lhsx;
    }


    public String getQllx() {
        return qllx;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public String getGyqk() {
        return gyqk;
    }

    public void setGyqk(String gyqk) {
        this.gyqk = gyqk;
    }

    public Date getDjsj() {
        return djsj;
    }

    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }

    public String getDbr() {
        return dbr;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    public String getFj() {
        return fj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }

    public String getCfsqr() {
        return cfsqr;
    }

    public void setCfsqr(String cfsqr) {
        this.cfsqr = cfsqr;
    }


    public String getLhcfqx() {
        return lhcfqx;
    }

    public void setLhcfqx(String lhcfqx) {
        this.lhcfqx = lhcfqx;
    }

    public String getJflx() {
        return jflx;
    }

    public void setJflx(String jflx) {
        this.jflx = jflx;
    }

    public String getIssx() {
        return issx;
    }

    public void setIssx(String issx) {
        this.issx = issx;
    }

    public String getIscd() {
        return iscd;
    }

    public void setIscd(String iscd) {
        this.iscd = iscd;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public Integer getCfsx() {
        return cfsx;
    }

    public void setCfsx(Integer cfsx) {
        this.cfsx = cfsx;
    }

    public Date getXfjssj() {
        return xfjssj;
    }

    public void setXfjssj(Date xfjssj) {
        this.xfjssj = xfjssj;
    }
}
